import setuptools
from distutils.core import setup

setup(
    name='Jinja2 Dev Server',
    version="0.0.2b1",
    author="Eamonn Nugent",
    author_email="eamonn.nugent@demilletech.net",
    packages=['jinja2-dev-server', ],
    license='MIT',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
)
